var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var Address_1;
import path from 'path';
import io from '@dao-xyz/peerbit-io-utils';
import { CID } from 'multiformats/cid';
import { serialize, deserialize } from '@dao-xyz/borsh';
import { variant, field } from '@dao-xyz/borsh';
const notEmpty = (e) => e !== '' && e !== ' ';
let Address = Address_1 = class Address {
    constructor(cid) {
        this.cid = cid;
    }
    toString() {
        return Address_1.join(this.cid);
    }
    equals(other) {
        return this.cid === other.cid;
    }
    static isValid(oaddress) {
        const address = oaddress.toString().replace(/\\/g, '/');
        const containsProtocolPrefix = (e, i) => !((i === 0 || i === 1) && address.toString().indexOf('/peerbit') === 0 && e === 'peerbit');
        const parts = address.toString()
            .split('/')
            .filter(containsProtocolPrefix)
            .filter(notEmpty);
        let accessControllerHash;
        const validateHash = (hash) => {
            const prefixes = ['zd', 'Qm', 'ba', 'k5'];
            for (const p of prefixes) {
                if (hash.indexOf(p) > -1) {
                    return true;
                }
            }
            return false;
        };
        try {
            accessControllerHash = validateHash(parts[0])
                ? CID.parse(parts[0]).toString()
                : null;
        }
        catch (e) {
            return false;
        }
        return accessControllerHash !== null;
    }
    static parse(oaddress) {
        if (!oaddress) {
            throw new Error(`Not a valid Peerbit address: ${oaddress}`);
        }
        if (!Address_1.isValid(oaddress)) {
            throw new Error(`Not a valid Peerbit address: ${oaddress}`);
        }
        const address = oaddress.toString().replace(/\\/g, '/');
        const parts = address.toString()
            .split('/')
            .filter((e, i) => !((i === 0 || i === 1) && address.toString().indexOf('/peerbit') === 0 && e === 'peerbit'))
            .filter(e => e !== '' && e !== ' ');
        return new Address_1(parts[0]);
    }
    static join(cid) {
        return (path.posix || path).join('/peerbit', cid);
    }
};
__decorate([
    field({ type: 'string' }),
    __metadata("design:type", String)
], Address.prototype, "cid", void 0);
Address = Address_1 = __decorate([
    variant(0),
    __metadata("design:paramtypes", [String])
], Address);
export { Address };
export const save = async (ipfs, thing, options = {}) => {
    const manifest = {
        data: serialize(thing)
    };
    const hash = await io.write(ipfs, options.format || 'dag-cbor', manifest, options);
    return Address.parse(Address.join(hash));
};
export const load = async (ipfs, address, into, options = {}) => {
    const manifest = await io.read(ipfs, address.cid, options);
    const der = deserialize(manifest.data, into);
    der.address = Address.parse(Address.join(address.cid));
    return der;
};
//# sourceMappingURL=io.js.map